@@ -32,23 +32,10 @@
 #include <KMessageBox>
 #include <krun.h>
 
+#include <QDesktopServices>
+
 using namespace Akonadi;
 
-static QString strippedDialNumber(const QString &number)
-{
-    QString result;
-
-    const int numberLength(number.length());
-    for (int i = 0; i < numberLength; ++i) {
-        const QChar character = number.at(i);
-        if (character.isDigit() || (character == QLatin1Char('+') && i == 0)) {
-            result += character;
-        }
-    }
-
-    return result;
-}
-
 void DialPhoneNumberAction::dialNumber(const KContacts::PhoneNumber &number)
 {
     // synchronize
@@ -64,15 +51,22 @@ void DialPhoneNumberAction::dialNumber(const KContacts::PhoneNumber &number)
         dialer = new QEkigaDialer(QStringLiteral("AkonadiContacts"));
     }
     if (dialer) {
-        if (!dialer->dialNumber(strippedDialNumber(number.number().trimmed()))) {
+        if (!dialer->dialNumber(number.normalizedNumber())) {
             KMessageBox::sorry(nullptr, dialer->errorMessage());
         }
         delete dialer;
         return;
     }
 
-    QString command = ContactActionsSettings::self()->phoneCommand();
+    if (ContactActionsSettings::self()->dialPhoneNumberAction() == ContactActionsSettings::UseSystemDefault) {
+        QUrl url;
+        url.setScheme(QStringLiteral("tel"));
+        url.setPath(number.normalizedNumber());
+        QDesktopServices::openUrl(url);
+        return;
+    }
 
+    QString command = ContactActionsSettings::self()->phoneCommand();
     if (command.isEmpty()) {
         KMessageBox::sorry(nullptr, i18n("There is no application set which could be executed.\nPlease go to the settings dialog and configure one."));
         return;
@@ -83,7 +77,7 @@ void DialPhoneNumberAction::dialNumber(const KContacts::PhoneNumber &number)
      * %n the number with all additional non-number characters removed
      */
     command = command.replace(QLatin1String("%N"), number.number());
-    command = command.replace(QLatin1String("%n"), strippedDialNumber(number.number().trimmed()));
+    command = command.replace(QLatin1String("%n"), number.normalizedNumber());
 
     KRun::runCommand(command, nullptr);
 }
