@@ -91,7 +91,7 @@ public:
      * connected to its default implementation provided by this class.
      * @param type the type of action to create
      */
-    QAction *createAction(Type type);
+    Q_REQUIRED_RESULT QAction *createAction(Type type);
 
     /**
      * Creates the action of the given type and adds it to the action collection
@@ -154,13 +154,13 @@ public:
      * Returns the list of collections that are currently selected.
      * The list is empty if no collection is currently selected.
      */
-    Akonadi::Collection::List selectedCollections() const;
+    Q_REQUIRED_RESULT Akonadi::Collection::List selectedCollections() const;
 
     /**
      * Returns the list of items that are currently selected.
      * The list is empty if no item is currently selected.
      */
-    Akonadi::Item::List selectedItems() const;
+    Q_REQUIRED_RESULT Akonadi::Item::List selectedItems() const;
 
     /**
      * @param names the list of names to set as collection properties page names
