@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -30,7 +30,7 @@ class CONTACTEDITOR_TESTS_EXPORT ContactEditorComboBox : public QComboBox
     Q_OBJECT
 public:
     explicit ContactEditorComboBox(QWidget *parent = nullptr);
-    ~ContactEditorComboBox();
+    ~ContactEditorComboBox() override;
 
 protected:
     QSize minimumSizeHint() const override;
